django-grpahql-oauth2
======================

*django-graphql-oauth2* is a Django application that provides
customizable OAuth2\-authentication for your Django projects.
ported `django-oauth2 <https://github.com/stormsherpa/django-oauth2-provider>`_ from rest to graphql inspired by `django-graphql-jwt <https://github.com/flavors/django-graphql-jwt>`_

Installation
------------
::

    pip install django-graphql-oauth2

License
-------

*django-graphql-oauth2* is a fork of  `django-oauth2 <https://github.com/stormsherpa/django-oauth2-provider>`_ which is released under the MIT License. Please see the LICENSE file for details.
